@@ -18,8 +18,8 @@ func testCommand(t *testing.T, cmd *cli.Command) {
 		assert.NotNil(t, cmd.Action, cmd.Name)
 	}
 
-	assert.NotEmpty(t, cmd.Usage)
-	assert.NotEmpty(t, cmd.Description)
+	assert.NotEmpty(t, cmd.Usage, "Required usage for command %s", cmd.Name)
+	assert.NotEmpty(t, cmd.Description, "Required description for command %s", cmd.Name)
 
 	for _, flag := range cmd.Flags {
 		switch v := flag.(type) {
@@ -45,7 +45,6 @@ func TestCommands(t *testing.T) {
 	act, err := newMock(ctx, u.StoreDir(""))
 	require.NoError(t, err)
 	require.NotNil(t, act)
-	ctx = act.cfg.WithConfig(ctx) //nolint:ineffassign
 
 	for _, cmd := range act.GetCommands() {
 		t.Run(cmd.Name, func(t *testing.T) {
