@@ -55,6 +55,15 @@ func (s *Action) IsInitialized(c *cli.Context) error {
 	out.Printf(ctx, logo)
 	out.Printf(ctx, "🌟 Welcome to gopass!")
 	out.Noticef(ctx, "No existing configuration found.")
+
+	contSetup, err := termio.AskForBool(ctx, "❓ Do you want to continue to setup?", false)
+	if err != nil {
+		return err
+	}
+	if contSetup {
+		return s.Setup(c)
+	}
+
 	out.Printf(ctx, "☝ Please run 'gopass setup'")
 
 	return exit.Error(exit.NotInitialized, err, "not initialized")
@@ -66,7 +75,10 @@ func (s *Action) Init(c *cli.Context) error {
 	path := c.String("path")
 	alias := c.String("store")
 
-	ctx = initParseContext(ctx, c)
+	ctx, err := initParseContext(ctx, c)
+	if err != nil {
+		return err
+	}
 	out.Printf(ctx, "🍭 Initializing a new password store ...")
 
 	if name := termio.DetectName(c.Context, c); name != "" {
@@ -93,13 +105,21 @@ func (s *Action) Init(c *cli.Context) error {
 	return nil
 }
 
-func initParseContext(ctx context.Context, c *cli.Context) context.Context {
+func initParseContext(ctx context.Context, c *cli.Context) (context.Context, error) {
 	if c.IsSet("crypto") {
-		ctx = backend.WithCryptoBackendString(ctx, c.String("crypto"))
+		var err error
+		ctx, err = backend.WithCryptoBackendString(ctx, c.String("crypto"))
+		if err != nil {
+			return ctx, exit.Error(exit.Unknown, err, "Failed to set crypto backend: %s", err)
+		}
 	}
 
 	if c.IsSet("storage") {
-		ctx = backend.WithStorageBackendString(ctx, c.String("storage"))
+		var err error
+		ctx, err = backend.WithStorageBackendString(ctx, c.String("storage"))
+		if err != nil {
+			return ctx, exit.Error(exit.Unknown, err, "Failed to set storage backend: %s", err)
+		}
 	}
 
 	if !backend.HasCryptoBackend(ctx) {
@@ -112,7 +132,15 @@ func initParseContext(ctx context.Context, c *cli.Context) context.Context {
 		ctx = backend.WithStorageBackend(ctx, backend.GitFS)
 	}
 
-	return ctx
+	sb := backend.GetStorageBackend(ctx)
+	if sb == backend.CryptFS {
+		out.Warning(ctx, "⚠ CryptFS is an experimental backend. Use at your own risk! ⚠")
+	}
+	if sb == backend.JJFS {
+		out.Warning(ctx, "⚠ JJFS is an experimental backend. Use at your own risk! ⚠")
+	}
+
+	return ctx, nil
 }
 
 func (s *Action) init(ctx context.Context, alias, path string, keys ...string) error {
@@ -138,9 +166,13 @@ func (s *Action) init(ctx context.Context, alias, path string, keys ...string) e
 	}
 
 	if len(keys) < 1 {
-		out.Notice(ctx, "Hint: Use 'gopass init <subkey> to use subkeys!'")
+		if crypto.Name() != "age" {
+			out.Notice(ctx, "Hint: Use 'gopass init <subkey> to use subkeys!'")
+		}
 		nk, err := cui.AskForPrivateKey(ctx, crypto, "🎮 Please select a private key for encrypting secrets:")
 		if err != nil {
+			out.Noticef(ctx, "Hint: Use 'gopass setup --crypto %s' to be guided through an initial setup instead of 'gopass init'", crypto.Name())
+
 			return fmt.Errorf("failed to read user input: %w", err)
 		}
 		keys = []string{nk}
