@@ -2,7 +2,6 @@ package action
 
 import (
 	"bytes"
-	"context"
 	"os"
 	"testing"
 
@@ -20,7 +19,7 @@ import (
 func TestList(t *testing.T) {
 	u := gptest.NewUnitTester(t)
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 	ctx = ctxutil.WithAlwaysYes(ctx, true)
 	ctx = ctxutil.WithInteractive(ctx, false)
 
@@ -119,7 +118,7 @@ foo2/bar2
 func TestListLimit(t *testing.T) {
 	u := gptest.NewUnitTester(t)
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 	ctx = ctxutil.WithAlwaysYes(ctx, true)
 	ctx = ctxutil.WithInteractive(ctx, false)
 
@@ -214,12 +213,12 @@ foo2/bar2
 }
 
 func TestRedirectPager(t *testing.T) {
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	var buf *bytes.Buffer
 	var subtree *tree.Root
 
-	cfg := config.NewNoWrites()
+	cfg := config.NewInMemory()
 	ctx = cfg.WithConfig(ctx)
 
 	// no pager
