@@ -2,12 +2,12 @@ package action
 
 import (
 	"bytes"
-	"context"
 	"os"
 	"path/filepath"
 	"testing"
 
 	"github.com/gokyle/twofactor"
+	"github.com/gopasspw/gopass/internal/config"
 	"github.com/gopasspw/gopass/internal/out"
 	"github.com/gopasspw/gopass/pkg/ctxutil"
 	"github.com/gopasspw/gopass/pkg/gopass/secrets"
@@ -19,7 +19,7 @@ import (
 func TestOTP(t *testing.T) {
 	u := gptest.NewUnitTester(t)
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 	ctx = ctxutil.WithAlwaysYes(ctx, true)
 	ctx = ctxutil.WithInteractive(ctx, false)
 
@@ -59,7 +59,12 @@ func TestOTP(t *testing.T) {
 
 	t.Run("copy to clipboard", func(t *testing.T) {
 		defer buf.Reset()
-		require.NoError(t, act.otp(ctx, "bar", "", true, false, false))
+		require.NoError(t, act.otp(ctx, "bar", "", true, false, false, false, false))
+	})
+
+	t.Run("copy to clipboard chained", func(t *testing.T) {
+		defer buf.Reset()
+		require.NoError(t, act.otp(ctx, "bar", "", true, false, false, true, false))
 	})
 
 	t.Run("write QR file", func(t *testing.T) {
