@@ -2,10 +2,10 @@ package action
 
 import (
 	"bytes"
-	"context"
 	"os"
 	"testing"
 
+	"github.com/gopasspw/gopass/internal/config"
 	"github.com/gopasspw/gopass/internal/out"
 	"github.com/gopasspw/gopass/pkg/ctxutil"
 	"github.com/gopasspw/gopass/tests/gptest"
@@ -16,7 +16,7 @@ import (
 func TestGit(t *testing.T) {
 	u := gptest.NewUnitTester(t)
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 	ctx = ctxutil.WithAlwaysYes(ctx, true)
 	ctx = ctxutil.WithInteractive(ctx, false)
 
@@ -56,6 +56,6 @@ func TestGit(t *testing.T) {
 	buf.Reset()
 
 	// GitPush
-	require.Error(t, act.RCSPush(c))
+	require.NoError(t, act.RCSPush(c))
 	buf.Reset()
 }
