@@ -13,8 +13,33 @@ import (
 	"github.com/urfave/cli/v2"
 )
 
-func (s *Action) entriesForCompleter(ctx context.Context) ([]readline.PrefixCompleterInterface, error) {
-	args := []readline.PrefixCompleterInterface{}
+type mindFlagsCompleter struct {
+	base readline.AutoCompleter
+}
+
+func (f *mindFlagsCompleter) Do(line []rune, pos int) ([][]rune, int) {
+	// Get the portion of the line up to the cursor and split to tokens
+	origInput := string(line[:pos])
+	tokens := strings.Fields(origInput)
+	filtered := make([]string, 0, len(tokens))
+	for _, tok := range tokens {
+		// Skip flag tokens
+		if strings.HasPrefix(tok, "-") {
+			continue
+		}
+		filtered = append(filtered, tok)
+	}
+	sanitized := strings.Join(filtered, " ")
+	// Add additional space if had one on original line
+	if len(origInput) > 0 && origInput[len(origInput)-1] == ' ' {
+		sanitized += " "
+	}
+
+	return f.base.Do([]rune(sanitized), len([]rune(sanitized)))
+}
+
+func (s *Action) entriesForCompleter(ctx context.Context) ([]*readline.PrefixCompleter, error) {
+	args := []*readline.PrefixCompleter{}
 	list, err := s.Store.List(ctx, tree.INF)
 	if err != nil {
 		return args, err
@@ -26,14 +51,14 @@ func (s *Action) entriesForCompleter(ctx context.Context) ([]readline.PrefixComp
 	return args, nil
 }
 
-func (s *Action) replCompleteRecipients(ctx context.Context, cmd *cli.Command) []readline.PrefixCompleterInterface {
-	subCmds := []readline.PrefixCompleterInterface{}
+func (s *Action) replCompleteRecipients(ctx context.Context, cmd *cli.Command) []*readline.PrefixCompleter {
+	subCmds := []*readline.PrefixCompleter{}
 	if cmd.Name == "remove" {
 		for _, r := range s.recipientsList(ctx) {
 			subCmds = append(subCmds, readline.PcItem(r))
 		}
 	}
-	args := []readline.PrefixCompleterInterface{}
+	args := []*readline.PrefixCompleter{}
 	args = append(args, readline.PcItem(cmd.Name, subCmds...))
 	for _, alias := range cmd.Aliases {
 		args = append(args, readline.PcItem(alias, subCmds...))
@@ -42,12 +67,12 @@ func (s *Action) replCompleteRecipients(ctx context.Context, cmd *cli.Command) [
 	return args
 }
 
-func (s *Action) replCompleteTemplates(ctx context.Context, cmd *cli.Command) []readline.PrefixCompleterInterface {
-	subCmds := []readline.PrefixCompleterInterface{}
+func (s *Action) replCompleteTemplates(ctx context.Context, cmd *cli.Command) []*readline.PrefixCompleter {
+	subCmds := []*readline.PrefixCompleter{}
 	for _, r := range s.templatesList(ctx) {
 		subCmds = append(subCmds, readline.PcItem(r))
 	}
-	args := []readline.PrefixCompleterInterface{}
+	args := []*readline.PrefixCompleter{}
 	args = append(args, readline.PcItem(cmd.Name, subCmds...))
 	for _, alias := range cmd.Aliases {
 		args = append(args, readline.PcItem(alias, subCmds...))
@@ -61,12 +86,12 @@ func (s *Action) prefixCompleter(c *cli.Context) *readline.PrefixCompleter {
 	if err != nil {
 		debug.Log("failed to list secrets: %s", err)
 	}
-	cmds := []readline.PrefixCompleterInterface{}
+	cmds := []*readline.PrefixCompleter{}
 	for _, cmd := range c.App.Commands {
 		if cmd.Hidden {
 			continue
 		}
-		subCmds := []readline.PrefixCompleterInterface{}
+		subCmds := []*readline.PrefixCompleter{}
 		switch cmd.Name {
 		case "config":
 			for _, k := range s.configKeys() {
@@ -135,7 +160,7 @@ READ:
 	for {
 		// check for context cancellation
 		select {
-		case <-c.Context.Done():
+		case <-c.Done():
 			return fmt.Errorf("user aborted")
 		default:
 		}
@@ -144,7 +169,7 @@ READ:
 		// the list of secrets may have changed, e.g. due to
 		// the user adding a new secret.
 		cfg := rl.GetConfig()
-		cfg.AutoComplete = s.prefixCompleter(c)
+		cfg.AutoComplete = &mindFlagsCompleter{base: s.prefixCompleter(c)}
 		if err := rl.SetConfig(cfg); err != nil {
 			debug.Log("Failed to set readline config: %s", err)
 
