@@ -30,11 +30,20 @@ func (s *Action) Setup(c *cli.Context) error {
 	team := c.String("alias")
 	create := c.Bool("create")
 
-	ctx = initParseContext(ctx, c)
+	ctx, err := initParseContext(ctx, c)
+	if err != nil {
+		return err
+	}
 
 	out.Printf(ctx, logo)
 	out.Printf(ctx, "🌟 Welcome to gopass!")
 	out.Printf(ctx, "🌟 Initializing a new password store ...")
+	if backend.HasCryptoBackend(ctx) {
+		out.Printf(ctx, "🔐 Using crypto backend: %s", backend.GetCryptoBackend(ctx))
+	}
+	if backend.HasStorageBackend(ctx) {
+		out.Printf(ctx, "💾 Using storage backend: %s", backend.GetStorageBackend(ctx))
+	}
 
 	if name := termio.DetectName(ctx, c); name != "" {
 		ctx = ctxutil.WithUsername(ctx, name)
@@ -81,6 +90,15 @@ func (s *Action) Setup(c *cli.Context) error {
 		return fmt.Errorf("failed to check private keys: %w", err)
 	}
 
+	// if a git remote is given, clone it and exit
+	if remote != "" && team == "" {
+		if err := s.clone(ctx, remote, "", ""); err != nil {
+			return fmt.Errorf("failed to clone remote %q: %w", remote, err)
+		}
+
+		return nil
+	}
+
 	// if a git remote and a team name are given attempt unattended team setup.
 	if remote != "" && team != "" {
 		if create {
@@ -120,7 +138,7 @@ func (s *Action) initCheckPrivateKeys(ctx context.Context, crypto backend.Crypto
 		out.Printf(ctx, "🔐 Cryptographic keys generated")
 	}
 
-	debug.Log("We have useable private keys")
+	debug.V(1).Log("We have useable private keys")
 
 	return nil
 }
