@@ -6,8 +6,8 @@ import (
 	"time"
 
 	"github.com/gopasspw/gopass/internal/hashsum"
-	"github.com/gopasspw/gopass/internal/set"
 	"github.com/gopasspw/gopass/pkg/debug"
+	"github.com/gopasspw/gopass/pkg/set"
 )
 
 type Finding struct {
