@@ -1,5 +1,4 @@
 //go:build !windows
-// +build !windows
 
 package cli
 
@@ -19,7 +18,8 @@ func TestEncrypt(t *testing.T) {
 	g.binary = "true"
 
 	_, err := g.Encrypt(ctx, []byte("foo"), nil)
-	require.NoError(t, err)
+	// No recipients are configured so it will fail
+	require.Error(t, err)
 }
 
 func TestDecrypt(t *testing.T) {
@@ -42,5 +42,6 @@ func TestGenerateIdentity(t *testing.T) {
 	g := &GPG{}
 	g.binary = "true"
 
-	require.NoError(t, g.GenerateIdentity(ctx, "foo", "foo@bar.com", "bar"))
+	_, err := g.GenerateIdentity(ctx, "foo", "foo@bar.com", "bar")
+	require.NoError(t, err)
 }
