@@ -69,6 +69,7 @@ attributes:
     charset: "0123456789"
     min: 1
     max: 64
+    always_prompt: true
   - name: "comment"
     type: "string"
 `))
@@ -88,18 +89,5 @@ attributes:
 	assert.Equal(t, "Entity", w.Templates[0].Attributes[1].Prompt, "wrong prompt")
 	assert.Equal(t, 1, w.Templates[0].Attributes[1].Min, "wrong min")
 	assert.Equal(t, "password", w.Templates[0].Attributes[2].Type, "wrong type")
-}
-
-func TestExtractHostname(t *testing.T) {
-	t.Parallel()
-
-	for in, out := range map[string]string{
-		"":                                     "",
-		"http://www.example.org/":              "www.example.org",
-		"++#+++#jhlkadsrezu 33 553q ++++##$§&": "jhlkadsrezu_33_553q",
-		"www.example.org/?foo=bar#abc":         "www.example.org",
-		"a test":                               "a_test",
-	} {
-		assert.Equal(t, out, extractHostname(in))
-	}
+	assert.True(t, w.Templates[0].Attributes[2].AlwaysPrompt, "wrong always_prompt")
 }
