@@ -1,5 +1,4 @@
 //go:build linux
-// +build linux
 
 package notify
 
@@ -7,7 +6,7 @@ import (
 	"context"
 	"os"
 
-	"github.com/godbus/dbus"
+	"github.com/godbus/dbus/v5"
 	"github.com/gopasspw/gopass/internal/config"
 	"github.com/gopasspw/gopass/pkg/debug"
 )
@@ -31,7 +30,7 @@ func Notify(ctx context.Context, subj, msg string) error {
 	if call.Err != nil {
 		debug.Log("DBus notification failure: %s", call.Err)
 
-		return err
+		return call.Err
 	}
 
 	return nil
