@@ -20,9 +20,11 @@ func TestNotify(t *testing.T) {
 func TestIcon(t *testing.T) {
 	t.Parallel()
 
-	fn := strings.TrimPrefix(iconURI(), "file://")
+	ctx := t.Context()
+
+	fn := strings.TrimPrefix(iconURI(ctx), "file://")
 	require.NoError(t, os.Remove(fn))
-	_ = iconURI()
+	_ = iconURI(ctx)
 	fh, err := os.Open(fn)
 	require.NoError(t, err)
 
