@@ -1,5 +1,4 @@
 //go:build !windows
-// +build !windows
 
 package updater
 
@@ -10,12 +9,13 @@ import (
 	"path/filepath"
 	"testing"
 
+	"github.com/gopasspw/gopass/internal/config"
 	"github.com/stretchr/testify/require"
 )
 
 //nolint:wrapcheck
 func TestIsUpdateable(t *testing.T) {
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 	oldExec := executable
 
 	defer func() {
@@ -47,7 +47,9 @@ func TestIsUpdateable(t *testing.T) {
 		{
 			name: "force update",
 			pre: func() error {
-				return os.Setenv("GOPASS_FORCE_UPDATE", "true")
+				t.Setenv("GOPASS_FORCE_UPDATE", "true")
+
+				return nil
 			},
 			exec: func(context.Context) (string, error) {
 				return "", nil
@@ -60,7 +62,9 @@ func TestIsUpdateable(t *testing.T) {
 		{
 			name: "update in gopath",
 			pre: func() error {
-				return os.Setenv("GOPATH", "/tmp/foo")
+				t.Setenv("GOPATH", "/tmp/foo")
+
+				return nil
 			},
 			exec: func(context.Context) (string, error) {
 				return "/tmp/foo/gopass", nil
