@@ -2,23 +2,20 @@ package main
 
 import (
 	"bytes"
-	"context"
 	"flag"
-	"fmt"
 	"os"
-	"runtime"
 	"testing"
 
-	"github.com/atotto/clipboard"
 	"github.com/blang/semver/v4"
 	"github.com/fatih/color"
+	"github.com/gopasspw/clipboard"
 	"github.com/gopasspw/gopass/internal/action"
 	"github.com/gopasspw/gopass/internal/backend"
 	"github.com/gopasspw/gopass/internal/backend/crypto/gpg"
 	"github.com/gopasspw/gopass/internal/config"
 	"github.com/gopasspw/gopass/internal/out"
-	"github.com/gopasspw/gopass/internal/set"
 	"github.com/gopasspw/gopass/pkg/ctxutil"
+	"github.com/gopasspw/gopass/pkg/set"
 	"github.com/gopasspw/gopass/tests/gptest"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
@@ -31,7 +28,11 @@ func TestVersionPrinter(t *testing.T) {
 	buf := &bytes.Buffer{}
 	vp := makeVersionPrinter(buf, semver.Version{Major: 1})
 	vp(nil)
-	assert.Equal(t, fmt.Sprintf("gopass 1.0.0 %s %s %s\n", runtime.Version(), runtime.GOOS, runtime.GOARCH), buf.String())
+
+	commit, _, _ := parseBuildInfo()
+
+	assert.Contains(t, buf.String(), "gopass 1.0.0")
+	assert.Contains(t, buf.String(), commit)
 }
 
 func TestGetVersion(t *testing.T) {
@@ -57,6 +58,7 @@ func TestSetupApp(t *testing.T) {
 var commandsWithError = set.Map([]string{
 	".age.identities.add",
 	".age.identities.remove",
+	".age.lock",
 	".alias.add",
 	".alias.remove",
 	".alias.delete",
@@ -88,7 +90,6 @@ var commandsWithError = set.Map([]string{
 	".move",
 	".otp",
 	".process",
-	".rcs.status",
 	".recipients.add",
 	".recipients.remove",
 	".show",
@@ -97,6 +98,7 @@ var commandsWithError = set.Map([]string{
 	".templates.remove",
 	".templates.show",
 	".unclip",
+	".reorg",
 })
 
 func TestGetCommands(t *testing.T) {
@@ -113,14 +115,18 @@ func TestGetCommands(t *testing.T) {
 	cfg := config.NewInMemory()
 	require.NoError(t, cfg.SetPath(u.StoreDir("")))
 
-	clipboard.Unsupported = true
+	clipboard.ForceUnsupported = true
 
 	ctx := config.NewContextInMemory()
 	ctx = ctxutil.WithAlwaysYes(ctx, true)
 	ctx = ctxutil.WithInteractive(ctx, false)
 	ctx = ctxutil.WithTerminal(ctx, false)
 	ctx = ctxutil.WithHidden(ctx, true)
-	ctx = backend.WithCryptoBackendString(ctx, "plain")
+	ctx, err := backend.WithCryptoBackendString(ctx, "plain")
+	require.NoError(t, err)
+	ctx = ctxutil.WithPasswordCallback(ctx, func(_ string, _ bool) ([]byte, error) {
+		return []byte("foobar"), nil
+	})
 
 	act, err := action.New(cfg, semver.Version{})
 	require.NoError(t, err)
@@ -131,7 +137,7 @@ func TestGetCommands(t *testing.T) {
 	c.Context = ctx
 
 	commands := getCommands(act, app)
-	assert.Len(t, commands, 41)
+	assert.Len(t, commands, 42)
 
 	prefix := ""
 	testCommands(t, c, commands, prefix)
@@ -141,7 +147,7 @@ func testCommands(t *testing.T, c *cli.Context, commands []*cli.Command, prefix
 	t.Helper()
 
 	for _, cmd := range commands {
-		if cmd.Name == "update" {
+		if cmd.Name == "update" || cmd.Name == "agent" {
 			continue
 		}
 
@@ -175,7 +181,7 @@ func testCommands(t *testing.T, c *cli.Context, commands []*cli.Command, prefix
 func TestInitContext(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := t.Context()
 	cfg := config.NewInMemory()
 
 	ctx = initContext(ctx, cfg)
