@@ -1,3 +1,4 @@
+// Package clipboard provides functions to copy and clear the clipboard.
 package clipboard
 
 import (
@@ -6,8 +7,8 @@ import (
 	"os"
 	"os/exec"
 
-	"github.com/atotto/clipboard"
 	"github.com/fatih/color"
+	"github.com/gopasspw/clipboard"
 	"github.com/gopasspw/gopass/internal/notify"
 	"github.com/gopasspw/gopass/internal/out"
 	"github.com/gopasspw/gopass/pkg/debug"
@@ -16,13 +17,15 @@ import (
 var (
 	// Helpers can be overridden at compile time, e.g. go build \
 	// -ldflags=='-X github.com/gopasspw/gopass/pkg/clipboard.Helpers=termux-api'.
-	Helpers = "xsel or xclip"
+	Helpers = "xsel, xclip or wl-clipboard"
 	// ErrNotSupported is returned when the clipboard is not accessible.
-	ErrNotSupported = fmt.Errorf("WARNING: No clipboard available. Install " + Helpers + ", provide $GOPASS_CLIPBOARD_COPY_CMD and $GOPASS_CLIPBOARD_CLEAR_CMD or use -f to print to console")
+	ErrNotSupported = fmt.Errorf("WARNING: No clipboard available. "+
+		"Install %s, provide $GOPASS_CLIPBOARD_COPY_CMD and $GOPASS_CLIPBOARD_CLEAR_CMD or use -f to print to console", Helpers)
 )
 
 // CopyTo copies the given data to the clipboard and enqueues automatic
-// clearing of the clipboard.
+// clearing of the clipboard. The name of the secret is passed for logging
+// and notifications. The timeout is in seconds.
 func CopyTo(ctx context.Context, name string, content []byte, timeout int) error {
 	debug.Log("Copying to clipboard: %s for %ds", name, timeout)
 
@@ -33,7 +36,7 @@ func CopyTo(ctx context.Context, name string, content []byte, timeout int) error
 
 			return fmt.Errorf("failed to call clipboard copy command: %w", err)
 		}
-	} else if clipboard.Unsupported {
+	} else if clipboard.IsUnsupported() {
 		out.Errorf(ctx, "%s", ErrNotSupported)
 		_ = notify.Notify(ctx, "gopass - clipboard", ErrNotSupported.Error())
 
@@ -53,7 +56,7 @@ func CopyTo(ctx context.Context, name string, content []byte, timeout int) error
 		return nil
 	}
 
-	if err := clear(ctx, name, content, timeout); err != nil {
+	if err := clearClip(ctx, name, content, timeout); err != nil {
 		_ = notify.Notify(ctx, "gopass - clipboard", "failed to clear clipboard")
 
 		return fmt.Errorf("failed to clear clipboard: %w", err)
@@ -65,7 +68,15 @@ func CopyTo(ctx context.Context, name string, content []byte, timeout int) error
 	return nil
 }
 
-func callCommand(ctx context.Context, cmd string, parameter string, stdinValue []byte) error {
+func copyToClipboard(ctx context.Context, content []byte) error {
+	if err := clipboard.WriteAll(ctx, content); err != nil {
+		return fmt.Errorf("failed to write to clipboard: %w", err)
+	}
+
+	return nil
+}
+
+func callCommand(_ context.Context, cmd string, parameter string, stdinValue []byte) error {
 	clipboardProcess := exec.Command(cmd, parameter)
 	stdin, err := clipboardProcess.StdinPipe()
 
