@@ -5,6 +5,7 @@ import (
 	"flag"
 	"testing"
 
+	"github.com/gopasspw/gopass/internal/config"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	"github.com/urfave/cli/v2"
@@ -13,7 +14,7 @@ import (
 func TestTerminal(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	assert.True(t, IsTerminal(ctx))
 	assert.True(t, IsTerminal(WithTerminal(ctx, true)))
@@ -23,7 +24,7 @@ func TestTerminal(t *testing.T) {
 func TestInteractive(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	assert.True(t, IsInteractive(ctx))
 	assert.True(t, IsInteractive(WithInteractive(ctx, true)))
@@ -33,7 +34,7 @@ func TestInteractive(t *testing.T) {
 func TestStdin(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	assert.False(t, IsStdin(ctx))
 	assert.True(t, IsStdin(WithStdin(ctx, true)))
@@ -43,7 +44,7 @@ func TestStdin(t *testing.T) {
 func TestGitCommit(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	assert.True(t, IsGitCommit(ctx))
 	assert.True(t, IsGitCommit(WithGitCommit(ctx, true)))
@@ -53,7 +54,7 @@ func TestGitCommit(t *testing.T) {
 func TestAlwaysYes(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	assert.False(t, IsAlwaysYes(ctx))
 	assert.True(t, IsAlwaysYes(WithAlwaysYes(ctx, true)))
@@ -63,7 +64,7 @@ func TestAlwaysYes(t *testing.T) {
 func TestProgressCallback(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	var foo bool
 
@@ -76,16 +77,16 @@ func TestProgressCallback(t *testing.T) {
 func TestAlias(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
-	assert.Equal(t, "", GetAlias(ctx))
-	assert.Equal(t, "", GetAlias(WithAlias(ctx, "")))
+	assert.Empty(t, GetAlias(ctx))
+	assert.Empty(t, GetAlias(WithAlias(ctx, "")))
 }
 
 func TestGitInit(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	assert.True(t, IsGitInit(ctx))
 	assert.True(t, IsGitInit(WithGitInit(ctx, true)))
@@ -95,7 +96,7 @@ func TestGitInit(t *testing.T) {
 func TestForce(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	assert.False(t, IsForce(ctx))
 	assert.True(t, IsForce(WithForce(ctx, true)))
@@ -105,36 +106,36 @@ func TestForce(t *testing.T) {
 func TestCommitMessage(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
-	assert.Equal(t, "", GetCommitMessage(ctx))
+	assert.Empty(t, GetCommitMessage(ctx))
 	assert.Equal(t, "foo", GetCommitMessage(WithCommitMessage(ctx, "foo")))
-	assert.Equal(t, "", GetCommitMessage(WithCommitMessage(ctx, "")))
+	assert.Empty(t, GetCommitMessage(WithCommitMessage(ctx, "")))
 }
 
 func TestCommitMessageBody(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	ctx2 := AddToCommitMessageBody(AddToCommitMessageBody(WithCommitMessage(ctx, "foo"), "bar"), "baz")
 	assert.Equal(t, "foo\n\nbar\nbaz", GetCommitMessageFull(ctx2))
 	assert.Equal(t, "foo", GetCommitMessage(ctx2))
 	assert.Equal(t, "bar\nbaz", GetCommitMessageBody(ctx2))
 	ctx2 = AddToCommitMessageBody(AddToCommitMessageBody(ctx, "bar"), "baz")
-	assert.Equal(t, "", GetCommitMessage(ctx2))
+	assert.Empty(t, GetCommitMessage(ctx2))
 	assert.Equal(t, "bar\nbaz", GetCommitMessageFull(ctx2))
 	assert.Equal(t, "bar\nbaz", GetCommitMessageBody(ctx2))
 	ctx2 = WithCommitMessage(ctx, "foo")
 	assert.Equal(t, "foo", GetCommitMessage(ctx2))
 	assert.Equal(t, "foo", GetCommitMessageFull(ctx2))
-	assert.Equal(t, "", GetCommitMessageBody(ctx2))
+	assert.Empty(t, GetCommitMessageBody(ctx2))
 }
 
 func TestComposite(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 	ctx = WithTerminal(ctx, false)
 	ctx = WithInteractive(ctx, false)
 	ctx = WithStdin(ctx, true)
@@ -181,7 +182,7 @@ func TestComposite(t *testing.T) {
 func TestGlobalFlags(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 	app := cli.NewApp()
 
 	fs := flag.NewFlagSet("default", flag.ContinueOnError)
@@ -200,7 +201,7 @@ func TestGlobalFlags(t *testing.T) {
 func TestImportFunc(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	ifunc := func(context.Context, string, []string) bool {
 		return true
@@ -215,7 +216,7 @@ func TestImportFunc(t *testing.T) {
 func TestHidden(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	assert.False(t, IsHidden(ctx))
 	assert.True(t, IsHidden(WithHidden(ctx, true)))
