@@ -18,7 +18,7 @@ func TestLoadCustomRules(t *testing.T) {
 	}
 
 	for k, v := range aliases {
-		require.NoError(t, cfg.Set("", "domain-alias."+k+".insteadOf", v))
+		require.NoError(t, cfg.Set("", "domain-alias."+k+".insteadof", v))
 	}
 
 	ctx := t.Context()
