@@ -15,13 +15,17 @@ func TestBaseConfig(t *testing.T) {
 	out, err := ts.run("config")
 	require.NoError(t, err)
 
-	wanted := `core.autopush = true
+	wanted := `age.agent-enabled = false
+age.agent-timeout = 0
+core.autopush = true
 core.autosync = true
 core.cliptimeout = 45
 core.exportkeys = false
+core.follow-references = false
 core.notifications = true
 `
-	wanted += "mounts.path = " + ts.storeDir("root")
+	wanted += "mounts.path = " + ts.storeDir("root") + "\n" +
+		"pwgen.xkcd-lang = en"
 
 	assert.Equal(t, wanted, out)
 
@@ -66,14 +70,18 @@ func TestMountConfig(t *testing.T) {
 	_, err = ts.run("config")
 	require.NoError(t, err)
 
-	wanted := `core.autopush = true
+	wanted := `age.agent-enabled = false
+age.agent-timeout = 0
+core.autopush = true
 core.autosync = true
 core.cliptimeout = 45
 core.exportkeys = false
+core.follow-references = false
 core.notifications = true
 `
 	wanted += "mounts.mnt/m1.path = " + ts.storeDir("m1") + "\n"
 	wanted += "mounts.path = " + ts.storeDir("root") + "\n"
+	wanted += "pwgen.xkcd-lang = en\n"
 	wanted += "recipients.mnt/m1.hash = 9a4c4b1e0eb9ade2e692ff948f43d9668145eca3df88ffff67e0e21426252907\n"
 
 	out, err := ts.run("config")
