@@ -4,6 +4,7 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestInit(t *testing.T) {
@@ -11,7 +12,7 @@ func TestInit(t *testing.T) {
 	defer ts.teardown()
 
 	out, err := ts.run("init")
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Contains(t, out, "Initializing a new password store ...")
 	assert.Contains(t, out, "initialized")
 
@@ -19,7 +20,7 @@ func TestInit(t *testing.T) {
 	defer ts.teardown()
 
 	out, err = ts.run("init " + keyID)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Contains(t, out, "initialized for")
 
 	ts = newTester(t)
@@ -28,7 +29,7 @@ func TestInit(t *testing.T) {
 	ts.initStore()
 	// try to init again
 	out, err = ts.run("init " + keyID)
-	assert.Error(t, err)
+	require.Error(t, err)
 
 	for _, o := range []string{
 		"found already initialized store at ",
